#!/bin/bash
#   http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/01_pdb2gmx.html

module load gromacs/2016.4

POSTFIX=_mpi
CORES=$(cat /proc/cpuinfo |grep processor |wc -l)
[ $CORES -gt 32 ] && NP=32 || NP=$CORES
export OMP_NUM_THREADS=$NP


[ -e clean ]      &&  /bin/cp -f clean/* .
[ -e 1AKI.pdb ]   ||  wget "http://www.rcsb.org/pdb/download/downloadFile.do?fileFormat=pdb&compression=NO&structureId=1AKI" -O 1AKI.pdb
[ -e ions.mdp ]   ||  wget "http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/Files/ions.mdp"  -O ions.mdp
[ -e minim.mdp ]  ||  wget "http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/Files/minim.mdp" -O minim.mdp
[ -e nvt.mdp ]    ||  wget "http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/Files/nvt.mdp"   -O nvt.mdp
[ -e npt.mdp ]    ||  wget "http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/Files/npt.mdp"   -O npt.mdp
[ -e md.mdp ]     ||  wget "http://www.bevanlab.biochem.vt.edu/Pages/Personal/justin/gmx-tutorials/lysozyme/Files/md.mdp"    -O md.mdp


#Step 1: Prepare the Topology
echo "Select Option 15:  OPLS-AA/L all-atom force field"
echo "15 0" > response
[ -e 1AKI_processed.gro ]     || gmx${POSTFIX} pdb2gmx -f 1AKI.pdb -o 1AKI_processed.gro -water spce   < response

#Step 3: Defining the Unit Cell & Adding Solvent
[ -e 1AKI_newbox.gro ]        || gmx${POSTFIX} editconf -f 1AKI_processed.gro -o 1AKI_newbox.gro -c -d 1.0 -bt cubic
[ -e 1AKI_solv.gro ]          || gmx${POSTFIX} solvate -cp 1AKI_newbox.gro -cs spc216.gro -o 1AKI_solv.gro -p topol.top

#Step 4: Adding Ions
[ -e ions.tpr ]               || gmx${POSTFIX} grompp -f ions.mdp -c 1AKI_solv.gro -p topol.top -o ions.tpr
echo "When prompted, choose group 13 "SOL" for embedding ions"
echo "13 0" > response
[ -e 1AKI_solv_ions.gro ]     || gmx${POSTFIX} genion -s ions.tpr -o 1AKI_solv_ions.gro -p topol.top -pname NA -nname CL -nn 8    < response

#Step 5: Energy Minimization
[ -e em.tpr ]                 || gmx${POSTFIX} grompp -f minim.mdp -c 1AKI_solv_ions.gro -p topol.top -o em.tpr
[ -e em.trr -a -e em.gro ]    || gmx${POSTFIX} mdrun -ntomp $NP -v -deffnm em
echo "At the prompt, type \"10 0\" to select Potential (10); zero (0) terminates input."
echo "10 0" > response
[ -e potential.xvg ]          || gmx${POSTFIX} energy -f em.edr -o potential.xvg  < response

#Step 6: Equilibration
[ -e nvt.tpr ]                || gmx${POSTFIX} grompp -f nvt.mdp -c em.gro -p topol.top -o nvt.tpr
#Now The Long run (about 60 mins):
[ -e nvt.trr -a -e nvt.gro ]  || gmx${POSTFIX} mdrun -ntomp $NP -v -deffnm nvt
echo "Type \"15 0\" at the prompt to select the temperature of the system and exit."
echo "15 0" > response
[ -e temperature.xvg ]        || gmx${POSTFIX} energy -f nvt.edr -o temperature.xvg  < response

#Step 7: Equilibration Part 2
[ -e npt.tpr ]                || gmx${POSTFIX} grompp -f npt.mdp -c nvt.gro -t nvt.cpt -p topol.top -o npt.tpr
#Another Long run (about 45 mins):
[ -e npt.trr -a -e npt.gro ]  || gmx${POSTFIX} mdrun -ntomp $NP -v -deffnm npt
echo "Type \"16 0\" at the prompt to select the pressure of the system and exit"
echo "16 0" > response
[ -e pressure.xvg ]           || gmx${POSTFIX} energy -f npt.edr -o pressure.xvg  < response
echo "Enter \"22 0\" at the prompt"
echo "22 0" > response
[ -e density.xvg ]            || gmx${POSTFIX} energy -f npt.edr -o density.xvg   < response

#Step 8: Production MD
[ -e md_0_1.tpr ]             || gmx${POSTFIX} grompp -f md.mdp -c npt.gro -t npt.cpt -p topol.top -o md_0_1.tpr


#Now the really long run (about 8 hours)
#[ -e md_0_1.trr -a -e md_0_1.gro ] || gmx${POSTFIX} mdrun -ntomp $NP -v -deffnm md_0_1
